from typing import Any

__all__ = ["RoadrunnerBootstrap5Config"]


def __getattr__(name: str) -> Any:
    if name == "RoadrunnerBootstrap5Config":
        from .entrypoint import RoadrunnerBootstrap5Config as _obj

        return _obj
    raise AttributeError(f"module '{__name__}' has no attribute '{name}'")
