# Generated by Django 3.2.13 on 2022-08-23 14:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('roadrunner_bs5', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='roadrunnerpage',
            name='noindex',
            field=models.BooleanField(default=False),
        ),
    ]
