{% load ocyan_thumbnail wagtailcore_tags wagtailimages_tags styling_tags sorl_thumbnail %}

<div class="parallax d-flex {{ self.height }} {% get_styling_classes self.styling %}">
    <div class="parallax-image-wrapper">
        <div class="parallax-image">
        {% if self.lazy %}
            {% lazy_responsive_image self.image.file %}
        {% else %}
            {% responsive_image self.image.file %}
        {% endif %}
        </div>
    </div>

    {% if self.overlay %}<span class="overlay"></span>{% endif %}
    {% if self.body %}
    <div class="parallax-lead-wrapper my-auto" {% get_styling self.styling %}>
        <div class="parallax-lead{% if self.horizontal_center %} mx-auto text-center{% endif %}{% if not self.styling.color %} text-white{% endif %}">
            {{ self.body|richtext }}
        </div>
    </div>
    {% endif %}
</div>