<div class="d-flex flex-wrap mx-auto" style="column-gap: 1rem; row-gap: 1rem;">
	<div style="max-width: 500px;">{{ children.body.render_form }}</div>
	<div>{{ children.image.render_form }}</div>
</div>