{% extends "layout.html" %}
{% load static ocyan_main wagtailcore_tags wagtailmetadata_tags %}

{% block extrahead %}
	{{ block.super }}
    {% meta_tags %}
    {% block page_meta %}{% endblock %}
{% endblock %}

{% block extrastyles %}
{{ block.super }}
<link rel="stylesheet" type="text/x-scss" href="{% static 'roadrunner_bs5/scss/style.scss' %}">
{% block roadunnercss %}
{% endblock %}
{% endblock %}

{% block extrascripts %}
    {{block.super}}
    {% block roadrunnerscripts %}{% endblock %}
{% endblock %}

{% block content_wrapper %}
<div class="content_wrapper">
    <div class="row m-0">

        <div class="col-sm-12 col-md-12 col-xs-12 p-0">
            {% block content %}
                {% for block in page.content %}
                    {% include_block block %}
                {% endfor %}
            {% endblock %}
        </div>

    </div>
</div>
{% endblock %}
