<div class="embed-responsive embed-responsive-{{ self.aspect_ratio }}">
    <iframe class="embed-responsive-item" src="https://maps.google.com/maps?hl={{LANGUAGE_CODE|default:"nl"}}&q={{ self.address|urlencode }}+({{ self.name|urlencode }})&ie=UTF8&t={{ self.view|urlencode }}&z={{ self.zoom|urlencode }}&iwloc=B&output=embed" frameborder="0" scrolling="no" marginheight="0" marginwidth="0"></iframe>
</div>
