# Generated by Django 3.2.13 on 2022-06-30 14:47

from django.db import migrations, models
import django.db.models.deletion
import rr.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('ocyan_plugin_wagtail', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RoadrunnerPage',
            fields=[
                ('abstractbasepage_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='ocyan_plugin_wagtail.abstractbasepage')),
                ('content', rr.fields.RoadRunnerField(blank=True, null=True)),
            ],
            options={
                'verbose_name': 'Pagemaker page',
                'verbose_name_plural': 'Pagemaker pages',
            },
            bases=('ocyan_plugin_wagtail.abstractbasepage',),
        ),
    ]
