# Generated by Django 4.2.11 on 2024-03-27 13:56

from django.db import migrations
import rr.fields


class Migration(migrations.Migration):

    dependencies = [
        ("roadrunner_bs5", "0003_rename_accordion_block"),
    ]

    operations = [
        migrations.AlterField(
            model_name="roadrunnerpage",
            name="content",
            field=rr.fields.RoadRunnerField(blank=True, null=True, use_json_field=True),
        ),
    ]
