@import "scss/variables";

.parallax, .roadrunner-slider .image-wrapper{
	&.px-small{
		min-height: 400px;
	}
	&.px-medium{
		min-height: 650px;
	}
	&.px-large{
		min-height: 800px;
	}
	&.vh-small{
		min-height: 30vh;
	}
	&.vh-medium{
		min-height: 45vh;
	}
	&.vh-large{
		min-height: 65vh;
	}
	&.vh-full{
		min-height: 100vh;
	}
	&.og-height{
		img{
			position: unset;
			width: auto;
			min-height: auto;
		}
	}
}
.sm-thick{
	min-height: 5px;
	background-color: var(--bs-primary);
	opacity: 1;
	max-width: 100px;
}
.tns-outer{
	button[data-action]{
		display: none;
	}
}

// FAQ
.sectioned-faq{
	.faq-left{
		button{
			padding: .75rem 1.5rem;
			margin-bottom: 1rem;
			background-color: unset !important;
			color: $body-color;
			text-align: left;
			border-radius: 0;
			border: 0;
			border-left: 2px solid transparent;
			outline: unset;
			box-shadow: unset;
			font-size: 1.25rem;
			font-weight: $headings-font-weight;
			transition: .3s ease;
			&.active{
				color: $body-color;
				border-left: 3px solid var(--bs-primary);
			}
			&:not(.active){
				padding-left: 3rem;
				opacity: .5;
			}
		}
	}
	.faq-right{
		.accordion-item{
			border: 0;
			border-bottom: 1px solid var(--bs-light);
			.accordion-body{
				padding: .75rem 1rem;
				padding-top: 0;
				b{
					font-weight: 800;
				}
				i{
					font-style: unset;
					text-decoration: underline;
				}
			}
			button.accordion-button{
				padding: .75rem 1rem;
				border: 0;
				background-color: unset;
				box-shadow: unset;
				outline: unset;
				cursor: pointer;
				font-weight: $headings-font-weight;
				&:after{
					display: none;
				}
				i{
					min-width: 14px;
				}
				.fa-chevron-down{
					font-weight: 900;
					color: var(--bs-primary);
					margin-right: 1rem;
					transition: .2s ease;
				}
				&:not(.collapsed){
					.fa-chevron-down{
						transform: rotate(180deg);
					}
				}
			}
		}
	}
}