{% include "roadrunner/partials/form_field.html" with child=children.name %}
{% include "roadrunner/partials/form_field.html" with child=children.address %}
<div class="d-flex w-100">
	<a class="nav-link py-3 fw-bold" data-bs-toggle="collapse" href="#all-{{prefix}}-2" data-bs-target="#all-{{prefix}}-2" aria-controls="all-{{prefix}}">
		Advanced settings
		<svg class="icon icon-cog default icon-small ps-1" aria-hidden="true" focusable="false">
			<use href="#icon-cog"/>
		</svg>
	</a>
</div>
<div class="collapse" id="all-{{prefix}}-2">
	{% include "roadrunner/partials/form_field.html" with child=children.aspect_ratio %}
	{% include "roadrunner/partials/form_field.html" with child=children.view %}
	{% include "roadrunner/partials/form_field.html" with child=children.zoom %}
</div>
